@@ -9,6 +9,7 @@
 mod cmd_2d_outline;
 mod cmd_centerline;
 mod cmd_knife_intersect;
+mod cmd_lsystems;
 mod cmd_simplify;
 mod cmd_voronoi;
 mod cmd_voronoi_mesh;
@@ -147,6 +148,7 @@ impl ToxicBlendService for TheToxicBlendService {
             "voronoi_mesh" => cmd_voronoi_mesh::command(a_command, map),
             "voronoi" => cmd_voronoi::command(a_command, map),
             "voxel" => cmd_voxel::command(a_command, map),
+            "lsystems" => cmd_lsystems::command(a_command, map),
             _ => Err(TBError::UnknownCommand(a_command.command.clone())),
         };
         // convert TBError to a valid Error message
